--- layout: default title: Customize and download slug: customize lead: Customize Bootstrap's components, Less variables, and jQuery plugins to get your very own version. ---
Heads up! The default value for `@brand-primary` has changed in the latest release to improve contrast and accessibility. Please double check your compiled CSS when upgrading.

Have an existing configuration? Upload your `config.json` to import it.

Drag and drop here, or manually upload.

Don't have one? That's okay—just start customizing the fields below.

# Less files

Choose which Less files to compile into your custom build of Bootstrap. Not sure which files to use? Read through the CSS and Components pages in the docs.

### Common CSS

Print media styles
Typography
Code
Grid system
Tables
Forms
Buttons
Responsive utilities

### Components

Glyphicons
Button groups
Input groups
Navs
Navbar
Breadcrumbs
Pagination
Pager
Labels
Badges
Jumbotron
Thumbnails
Alerts
Progress bars
Media items
List groups
Panels
Responsive embed
Wells
Close icon

### JavaScript components

Component animations (for JS)
Dropdowns
Tooltips
Popovers
Modals
Carousel

# jQuery plugins

Choose which jQuery plugins should be included in your custom JavaScript files. Unsure what to include? Read the JavaScript page in the docs.

#### Linked to components

Alert dismissal
Advanced buttons
Carousel functionality
Dropdowns
Modals
Tooltips
Popovers (requires Tooltips)
Togglable tabs

#### Magic

Affix
Collapse
Scrollspy
Transitions (required for any kind of animation)

#### Produces two files

All checked plugins will be compiled into a readable `bootstrap.js` and a minified `bootstrap.min.js`. We recommend you use the minified version in production.

#### jQuery required

All plugins require the latest version of jQuery to be included.

# Less variables

Customize Less variables to define colors, sizes and more inside your custom CSS stylesheets.

{% include customizer-variables.html %}

# Download

Hooray! Your custom version of Bootstrap is now ready to be compiled. Just click the button below to finish the process.